"use strict";(self.webpackChunkbqscales=self.webpackChunkbqscales||[]).push([[779],{330:e=>{e.exports=JSON.parse('{"name":"bqscales","version":"0.3.7","description":"Grammar of Graphics in Python","keywords":["jupyter","jupyterlab","jupyterlab-extension","widgets"],"files":["lib/**/*.js","lib/**/*.ts","dist/*.js"],"homepage":"https://github.com/bqplot/bqscales","bugs":{"url":"https://github.com/bqplot/bqscales/issues"},"license":"Apache","author":{"name":"Bqplot development team"},"main":"lib/index.js","types":"./lib/index.d.ts","repository":{"type":"git","url":"https://github.com/bqplot/bqscales"},"scripts":{"build":"yarn run build:lib && yarn run build:nbextension && yarn run build:labextension","build:lib":"tsc","build:nbextension":"webpack","build:labextension":"jupyter labextension build .","clean":"yarn run clean:lib && yarn run clean:nbextension && yarn run clean:labextension","clean:lib":"rimraf lib","clean:nbextension":"rimraf bqscales/nbextension/static/index.js","clean:labextension":"rimraf bqscales/labextension","prepack":"npm run build","test":"npm run test:chrome","test:chrome":"karma start --browsers=Chrome tests/karma.conf.js","test:debug":"karma start --browsers=Chrome --singleRun=false --debug=true tests/karma.conf.js","test:firefox":"karma start --browsers=Firefox tests/karma.conf.js","test:ie":"karma start --browsers=IE tests/karma.conf.js","watch":"npm-run-all -p watch:*","watch:lib":"tsc -w","watch:nbextension":"webpack --watch","prettier:check":"prettier src --check","prettier:fix":"prettier src --write","eslint:check":"eslint src --ext .ts","eslint:fix":"eslint src --ext .ts --fix"},"dependencies":{"@jupyter-widgets/base":"^2 || ^3 || ^4 || ^5 || ^6","@lumino/application":"^1.7.3 || ^2","@lumino/widgets":"^1.9.3 || ^2","d3-array":"^2.4.0","d3-geo":"^1.11.9","d3-scale":"^3.2.1","underscore":"^1.9.2"},"devDependencies":{"@jupyterlab/builder":"^4","@types/d3-array":"^2.0.0","@types/d3-geo":"^1.11.1","@types/d3-scale":"^2.1.1","@types/expect.js":"^0.3.29","@types/mocha":"^7.0.1","@types/node":"^13.7.0","@types/webpack-env":"^1.15.1","@typescript-eslint/eslint-plugin":"^4.19.0","@typescript-eslint/parser":"^4.19.0","babel-polyfill":"^6.26.0","eslint":"^7.22.0","eslint-config-prettier":"^8.1.0","eslint-config-standard":"^16.0.2","eslint-plugin-import":"^2.22.1","eslint-plugin-node":"^11.1.0","eslint-plugin-prettier":"^3.3.1","eslint-plugin-promise":"^4.2.1","expect.js":"^0.3.1","fs-extra":"^7.0.0","karma":"^6.3.14","karma-chrome-launcher":"^3.1.0","karma-firefox-launcher":"^1.3.0","karma-ie-launcher":"^1.0.0","karma-mocha":"^1.3.0","karma-mocha-reporter":"^2.2.5","karma-typescript":"^4.1.1","karma-typescript-es6-transform":"^4.1.1","mkdirp":"^0.5.1","mocha":"^7.0.1","npm-run-all":"^4.1.3","prettier":"^2.2.1","rimraf":"^2.6.2","source-map-loader":"^0.2.4","ts-loader":"^6.2.1","typescript":"^5","webpack":"^5.61","webpack-cli":"^4"},"jupyterlab":{"extension":"lib/plugin","webpackConfig":"webpack.lab.config.js","outputDir":"bqscales/labextension","sharedPackages":{"@jupyter-widgets/base":{"bundled":false,"singleton":true},"d3-array":{"bundled":true,"singleton":false},"d3-geo":{"bundled":true,"singleton":false},"d3-scale":{"bundled":true,"singleton":false},"underscore":{"bundled":true,"singleton":false}}}}')},779:(e,a,r)=>{r.r(a),r.d(a,{Albers:()=>M.mH,AlbersModel:()=>w.pF,AlbersUSA:()=>M.BA,AlbersUSAModel:()=>w.MG,ColorScale:()=>u.w,ColorScaleModel:()=>d.r,DateColorScale:()=>y.I,DateColorScaleModel:()=>h.H,DateScale:()=>k.R,DateScaleModel:()=>S.y,EquiRectangular:()=>M.xX,EquiRectangularModel:()=>w.QF,GeoScale:()=>M.AT,GeoScaleModel:()=>w.dc,Gnomonic:()=>M.DH,GnomonicModel:()=>w.ql,LinearScale:()=>c.k,LinearScaleModel:()=>o.T,LogScale:()=>x.j,LogScaleModel:()=>f.g,MODULE_NAME:()=>l.pW,MODULE_VERSION:()=>l.e$,Mercator:()=>M.wJ,MercatorModel:()=>w.R2,OrdinalColorScale:()=>m.J,OrdinalColorScaleModel:()=>g.E,OrdinalScale:()=>b.U,OrdinalScaleModel:()=>p.T,Orthographic:()=>M.LA,OrthographicModel:()=>w.GC,SEMVER_RANGE:()=>l.pF,Scale:()=>i.F,ScaleModel:()=>n.G,Stereographic:()=>M.bC,StereographicModel:()=>w.SM,colorbrewer:()=>t.f,convertToDate:()=>o.z,cycleColors:()=>s.tQ,cycleColorsFromScheme:()=>s.so,getLinearScale:()=>s.aW,getLinearScaleRange:()=>s.HL,getOrdinalScale:()=>s.ok,getOrdinalScaleRange:()=>s.DM,isColorScale:()=>u.S,isDateColorScale:()=>y.u,isDateScale:()=>k.X,isLinearScale:()=>c.Q,isLogScale:()=>x.F,isOrdinalScale:()=>b.w});var l=r(797),t=r(917),s=r(773),n=r(50),i=r(75),o=r(275),c=r(260),p=r(271),b=r(120),d=r(301),u=r(566),m=r(431),g=r(398),h=r(121),y=r(578),S=r(726),k=r(543),f=r(864),x=r(225),w=r(947),M=r(284)},797:(e,a,r)=>{r.d(a,{e$:()=>t,pF:()=>s,pW:()=>n});const l=r(330),t=l.version,s="^"+t,n=l.name}}]);